package com.ygtx.worklog.mapper;

import java.util.List;
import com.ygtx.worklog.domain.Project;

/**
 * 项目Mapper接口
 *
 * @author ruoyi
 * @date 2025-10-21
 */
public interface ProjectMapper
{
    /**
     * 查询项目
     *
     * @param id 项目主键
     * @return 项目
     */
    public Project selectProjectById(Long id);

    /**
     * 查询项目列表
     *
     * @param project 项目
     * @return 项目集合
     */
    public List<Project> selectProjectList(Project project);

    /**
     * 新增项目
     *
     * @param project 项目
     * @return 结果
     */
    public int insertProject(Project project);

    /**
     * 修改项目
     *
     * @param project 项目
     * @return 结果
     */
    public int updateProject(Project project);

    /**
     * 删除项目
     *
     * @param id 项目主键
     * @return 结果
     */
    public int deleteProjectById(Long id);

    /**
     * 批量删除项目
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProjectByIds(Long[] ids);

    /**
     * 根据项目编号查询项目
     *
     * @param projectCode 项目编号
     * @return 项目
     */
    public Project selectProjectByCode(String projectCode);
}
